@@ -26,13 +26,20 @@ def get_pub_socket(context, config, linger=100) -> zmq.Socket:
     return socket
 
 
-def wait_for_connection(dispatcher: MessageDispatcher, pub_socket, pub_lock=None, timeout=100):
+def wait_for_connection(dispatcher: MessageDispatcher, pub_socket=None, pub_lock=None, timeout=100):
     """
     waits until the pub_socket's messages can be received at the dispatcher.
-    This dispatcher needs to run in a seoarate thread as this method is blocking
+    This dispatcher needs to run in a separate thread as this method is blocking
     :param pub_lock: optionally locks the lock during publishing
     """
 
+    if pub_socket is None:
+        from openmodule.core import core
+        current_core = core()
+        assert current_core, "either a core must be running or you have to pass a pub_socket"
+        pub_socket = current_core.pub_socket
+        pub_lock = current_core.pub_lock
+
     pub_lock = pub_lock or contextlib.nullcontext()
     received = False
 
@@ -44,7 +51,7 @@ def wait_for_connection(dispatcher: MessageDispatcher, pub_socket, pub_lock=None
     random_topic = "__ping_" + "".join(random.choices(string.ascii_letters, k=10))
     random_topic = random_topic.encode()
 
-    listener = dispatcher.register_handler(random_topic, ZMQMessage, handler, register_schema=False)
+    listener = dispatcher.register_handler(random_topic, ZMQMessage, handler, register_schema=False, match_type=False)
 
     check_delay = 0.1
     check_iterations = int(timeout / check_delay) + 1
