@@ -1,7 +1,7 @@
 import re
 from datetime import datetime, timedelta, tzinfo
 from enum import Enum
-from typing import List, Optional, Union
+from typing import List, Optional, Union, Dict
 
 from dateutil import rrule, tz
 from dateutil.parser import parse
@@ -9,7 +9,6 @@ from dateutil.rrule import rrulestr
 from dateutil.tz import UTC
 from pydantic import validator, Field
 
-from openmodule.config import settings
 from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway, timezone_validator, datetime_to_timestamp
 
 
@@ -62,6 +61,8 @@ class Access(OpenModuleModel):
     zone: Optional[str]
     occupant_check: bool = False
     infos: Optional[dict] = {}
+    cost_entries: List[dict] = []
+    clearing: Optional[str]
     user: str
 
     _check_recurrence = validator("recurrence", allow_reuse=True)(check_recurrence)
@@ -145,6 +146,13 @@ class BackendRegisterMessage(ZMQMessage):
     type: str = "register"
 
 
+class BackendUnregisterMessage(ZMQMessage):
+    """
+    sent by a backend if it shuts down and wants to unregister itself
+    """
+    type: str = "unregister"
+
+
 class AccessRequest(OpenModuleModel):
     """
     The AccessRequest Model
@@ -152,13 +160,23 @@ class AccessRequest(OpenModuleModel):
     name: str
     gateway: Optional[Gateway] = None
     medium_type: MediumType
-    id: str
+    medium_id: str = Field(..., alias="id")
+
+    class Config:
+        # allows setting attributes both via the alias, and the field name.
+        # is used to rename old variables which are hard to understand by their name (e.g. id -> medium id)
+        allow_population_by_field_name = True
 
 
 class MediumAccesses(OpenModuleModel):
     accesses: List[Access]
-    id: str
-    type: str
+    medium_id: str = Field(..., alias="id")
+    medium_type: str = Field(..., alias="type")
+
+    class Config:
+        # allows setting attributes both via the alias, and the field name.
+        # is used to rename old variables which are hard to understand by their name (e.g. id -> medium id)
+        allow_population_by_field_name = True
 
 
 class AccessResponse(OpenModuleModel):
@@ -167,11 +185,11 @@ class AccessResponse(OpenModuleModel):
 
 
 class CountMessage(ZMQMessage):
-    resource: str = settings.RESOURCE
+    type: str = "count"
     user: str
     gateway: Gateway
     medium_type: MediumType
-    id: str
+    medium_id: str = Field(..., alias="id")
     count: int
     transaction_id: str
     zone: str
@@ -184,6 +202,53 @@ class CountMessage(ZMQMessage):
     previous_transaction_id: Optional[List[str]]  # double_entry, choose_random error
     previous_user: Optional[str]  # user_changed error
     previous_medium_type: Optional[str]  # medium_changed, medium_id_changed error
-    previous_id: Optional[str]  # medium_changed, medium_id_changed error
+    previous_medium_id: Optional[str] = Field(None,  # medium_changed, medium_id_changed error
+                                              alias="previous_medium_id")
     chosen: Optional[dict]  # choose_random error
 
+    class Config:
+        # allows setting attributes both via the alias, and the field name.
+        # is used to rename old variables which are hard to understand by their name (e.g. id -> medium id)
+        allow_population_by_field_name = True
+
+
+class SessionStartMessage(ZMQMessage):
+    type: str = "start"
+
+    id: str
+    user_id: Optional[str]
+    zone_id: str
+    cost_table: dict
+    clearing: Optional[str]
+    access_infos: Optional[dict]
+    serviceable: bool
+
+    entry_time: datetime
+    entry_data: Dict
+
+    _tz_entry_time = timezone_validator("entry_time")
+
+
+class SessionFinishMessage(ZMQMessage):
+    type: str = "finish"
+
+    id: str
+    user_id: Optional[str]
+    zone_id: str
+    cost_table: dict
+    clearing: Optional[str]
+    access_infos: Optional[dict]
+    serviceable: bool
+
+    entry_time: datetime
+    entry_data: Dict
+    exit_time: datetime
+    exit_data: Dict
+
+    payment_lock_at: Optional[datetime]
+    payment_lock_until: Optional[datetime]
+
+    _tz_entry_time = timezone_validator("entry_time")
+    _tz_exit_time = timezone_validator("exit_time")
+    _tz_payment_lock_at = timezone_validator("payment_lock_at")
+    _tz_payment_lock_until = timezone_validator("payment_lock_until")
