@@ -2,10 +2,10 @@ import logging
 from typing import List
 
 from openmodule.core import OpenModuleCore
-from openmodule.models.base import ZMQMessage
-from openmodule.rpc.server import RPCServer
 from openmodule.models.backend import AccessRequest, AccessResponse, CountMessage, MediumAccesses, Access, \
-    BackendRegisterMessage, BackendRegisterRequestMessage
+    BackendRegisterMessage, BackendRegisterRequestMessage, BackendUnregisterMessage, SessionStartMessage, \
+    SessionFinishMessage
+from openmodule.rpc.server import RPCServer
 
 
 class Backend:
@@ -26,8 +26,9 @@ class Backend:
         self.register_at_controller()
         self.core.messages.register_handler(b"count", CountMessage, self.handle_message)
         self.core.messages.register_handler(b"backend", BackendRegisterRequestMessage,
-                                            self.handle_backend_register_request,
-                                            match_type=True)
+                                            self.handle_backend_register_request)
+        self.core.messages.register_handler(b"session", SessionStartMessage, self.handle_session_start_message)
+        self.core.messages.register_handler(b"session", SessionFinishMessage, self.handle_session_finish_message)
 
     def register_rpcs(self, rpc_server: RPCServer):
         rpc_server.add_filter(self._backend_filter, "backend", "auth")
@@ -64,18 +65,50 @@ class Backend:
         """
         raise NotImplementedError()
 
+    def check_in_session(self, message: SessionStartMessage):
+        """
+       this method should check in the user of the message in the backend
+        it should raise an Exception if it fails
+       :param message: SessionStartMessage
+       """
+        raise NotImplementedError()
+
+    def check_out_session(self, message: SessionFinishMessage):
+        """
+        this method should check out the user of the message of the backend
+        :param message: SessionFinishMessage
+        """
+        raise NotImplementedError()
+
     def shutdown(self):
+        self.unregister_at_controller()
+
+    def handle_session_start_message(self, message: SessionStartMessage):
         """
-        this method should be used if a shutdown routine is required
+        Checks the user in with the data of the session start message
         """
-        pass
+        self.log.debug(f"received a session check in message for user {message.user_id}")
+        try:
+            self.check_in_session(message)
+        except Exception as e:
+            self.log.exception(f"Error in session check in for user {message.user_id}", extra=message.dict())
+
+    def handle_session_finish_message(self, message: SessionFinishMessage):
+        """
+        Checks the user out with the data of the session finish message
+        """
+        self.log.debug(f"received a session check out message for user {message.user_id}")
+        try:
+            self.check_out_session(message)
+        except Exception as e:
+            self.log.exception(f"Error in session check out for user {message.user_id}", extra=message.dict())
 
     def handle_message(self, message):
         """
         Checks the user in/out based on the received CountMessage
         """
         try:
-            self.log.debug(f"received a check {message.gateway.direction} messge for user {message.user}")
+            self.log.debug(f"received a check {message.gateway.direction} message for user {message.user}")
             if message.gateway.direction == "in":
                 self.check_in(message)
             else:
@@ -96,16 +129,22 @@ class Backend:
         except Exception as e:
             self.log.exception(f"check access request had an internal error {gate_log_string}")
             return AccessResponse(success=False,
-                                  medium=MediumAccesses(accesses=[], id=request.id, type=request.medium_type))
+                                  medium=MediumAccesses(accesses=[], id=request.medium_id, type=request.medium_type))
 
         if accesses:
-            self.log.info(f"{request.id}:{request.medium_type} has {len(accesses)} permissions {gate_log_string}")
-            return AccessResponse(success=True,
-                                  medium=MediumAccesses(id=request.id, type=request.medium_type, accesses=accesses))
+            self.log.info(
+                f"{request.medium_id}:{request.medium_type} has {len(accesses)} permissions {gate_log_string}"
+            )
+            return AccessResponse(
+                success=True,
+                medium=MediumAccesses(medium_id=request.medium_id, medium_type=request.medium_type, accesses=accesses)
+            )
         else:
-            self.log.info(f"{request.id} medium {request.medium_type} has NO parking permissions {gate_log_string}")
+            self.log.info(
+                f"{request.medium_id} medium {request.medium_type} has NO parking permissions {gate_log_string}"
+            )
             return AccessResponse(success=True,
-                                  medium=MediumAccesses(accesses=[], id=request.id, type=request.medium_type))
+                                  medium=MediumAccesses(accesses=[], id=request.medium_id, type=request.medium_type))
 
     def handle_backend_register_request(self, _):
         """
@@ -115,3 +154,6 @@ class Backend:
 
     def register_at_controller(self):
         self.core.publish(BackendRegisterMessage(), b"backend")
+
+    def unregister_at_controller(self):
+        self.core.publish(BackendUnregisterMessage(), b"backend")
