@@ -351,12 +351,20 @@ class _TestRPCRequest(BaseModel):
     we do not want to depend on openmodule, this is a minimal version of the zmq message for the rpc function
     """
     timestamp: float = Field(default_factory=time.time)
-    resource: Optional[str] = settings.RESOURCE
+    resource: Optional[str] = None
     name: str
     type: str
     rpc_id: UUID
     request: Optional[Dict]
 
+    def __init__(self, **kwargs):
+        resource = kwargs.pop("resource")
+        if not resource:
+            # this avoids evaluating settings.RESOURCE if resource is set in order to not trigger the settings module
+            # to start up unnecessarily (and maybe throw import errors)
+            resource = settings.RESOURCE
+        super().__init__(resource=resource, **kwargs)
+
 
 class ZMQProcotol(str, Enum):
     inproc = "inproc://"
@@ -368,10 +376,14 @@ class ZMQTestMixin(TestCase):
     rpc_channels: List[Union[bytes, str]] = []
     protocol: ZMQProcotol = "inproc://"
 
-    zmq_broker: TestBroker
-    zmq_client: TestClient
+    zmq_broker: TestBroker = None
+    zmq_client: TestClient = None
+
+    _cleanup_called = False
 
     def setUp(self):
+        self._cleanup_called = False
+
         super(ZMQTestMixin, self).setUp()
 
         assert self.protocol in ["tcp://", "inproc://"], "only tcp:// and inproc:// protocols are allowed"
@@ -388,15 +400,13 @@ class ZMQTestMixin(TestCase):
             BROKER_PUB=pub
         )
         self.addCleanup(settings.reset)
+        self.addCleanup(self._cleanup)
 
         self.zmq_broker = TestBroker(settings.BROKER_SUB, settings.BROKER_PUB)
-
         self.zmq_broker.start()
-        self.addCleanup(self.zmq_broker.stop)
 
         self.zmq_client = TestClient(self.zmq_broker)
         self.zmq_client.start()
-        self.addCleanup(self.zmq_client.stop)
 
         topics = set(self.topics + [f"rpc-rep-{x}" for x in self.rpc_channels])
         topics = [x.encode("ascii") if isinstance(x, str) else x for x in topics]
@@ -416,7 +426,7 @@ class ZMQTestMixin(TestCase):
         """
         random_topic = "_test" + "".join(random.choices(string.ascii_letters, k=10))
         random_topic = random_topic.encode()
-        dispatcher.register_handler(random_topic, BaseModel, handler, register_schema=False)
+        dispatcher.register_handler(random_topic, BaseModel, handler, register_schema=False, match_type=False)
 
         for x in range(self.zmq_client.startup_check_iterations):
             self.zmq_client.send(random_topic, {"type": "connection-check"})
@@ -431,10 +441,26 @@ class ZMQTestMixin(TestCase):
     def zmq_config(self):
         return settings
 
+    def _cleanup(self):
+        if self._cleanup_called:
+            return
+
+        # this is a bit hacky, we always want the broker to stop first so the lingering
+        # socket detection works properly, but this is not possible if the testcase fails
+        # during setup. in this case the cleanup is run via cleanup at the end
+        if self.zmq_client:
+            self.zmq_client.stop()
+
+        if self.zmq_broker:
+            self.zmq_broker.stop()
+
+        self._cleanup_called = True
+
     def tearDown(self):
         assert hasattr(self, "zmq_client"), (
             "testcase has no zmq_client member, did you forget to call super().setUp()?"
         )
+        self._cleanup()
         super(ZMQTestMixin, self).tearDown()
         Schema.to_file()
 
