@@ -180,6 +180,17 @@ class ConfigYamlTest(EnvTestCase):
         self.assertIsNone(model.some, msg="Not parsed custom elements must be none")
         self.assertEqual(model.test, "string")
 
+    def test_empty_yml(self):
+        yaml = ""
+
+        class TestModel(OpenModuleModel):
+            some: Optional[Any]
+
+        with temp_file(yaml) as f:
+            model = config.yaml(TestModel, f)
+
+        self.assertIsNone(model.some, msg="Not parsed custom elements must be none")
+
 
 class LegacyConfigSupportTest(EnvTestCase):
     def test_broker_pub(self):
@@ -276,9 +287,9 @@ class LazyConfigTest(TestCase):
         self.assertEqual("bsdf", settings.TEST)
         del os.environ["SETTINGS_MODULE"]
 
-    @override_context(NAME="ABC")
+    @override_settings(NAME="ABC")
     def test_overwrite(self):
-        @override_context(NAME="ASDF")
+        @override_settings(NAME="ASDF")
         def asdf():
             self.assertEqual("ASDF", settings.NAME)
             self.assertTrue(settings._wrapped.is_overridden("NAME"))
@@ -289,6 +300,15 @@ class LazyConfigTest(TestCase):
         self.assertEqual("ABC", settings.NAME)
         self.assertTrue(settings._wrapped.is_overridden("NAME"))
 
+    def test_override_var_which_does_not_exist(self):
+        @override_settings(VAR_DOES_NOT_EXIST=True)
+        def testfunction():
+            self.assertEqual(True, settings.VAR_DOES_NOT_EXIST)
+
+        self.assertFalse(hasattr(settings, "VAR_DOES_NOT_EXIST"))
+        testfunction()
+        self.assertFalse(hasattr(settings, "VAR_DOES_NOT_EXIST"))
+
     def test_context(self):
         settings.configure(test_config)
         self.assertEqual("THIS_IS_MY_NAME", settings.NAME)
